// src/index.ts
import { v4 as uuidv4 } from "uuid";
async function getJsSafeUUID() {
  const randomUUID = uuidv4;
  const busterId = `r${randomUUID()}`;
  const safeUUID = busterId.substring(0, 9);
  return safeUUID;
}
function forceInlineModule({ inlineModules = [] }) {
  const codeBuffer = /* @__PURE__ */ new Map();
  return {
    name: "transform-code",
    enforce: "pre",
    resolveId: {
      async handler(source, importer, options) {
        if (inlineModules.some((item) => source.includes(item))) {
          const resolution = await this.resolve(source, importer, {
            skipSelf: true,
            ...options
          });
          if (!resolution)
            return;
          const code = await this.load({ id: resolution.id });
          codeBuffer.set(source, code);
          const buster = await getJsSafeUUID();
          return { id: `\0${source}-cache?${buster}` };
        }
      }
    },
    load: {
      async handler(id) {
        if (id.startsWith("\0") && id.includes("-cache?")) {
          const [originalmodule, buster] = id.split("-cache?");
          const cb = codeBuffer.get(originalmodule.substring(1));
          const code = cb.code += `
 export const ${buster} = 1;`;
          return { code, map: { mappings: "" } };
        }
      }
    }
  };
}
export {
  forceInlineModule
};
